[−][src]Module libcli::args
Argument parser
Parses and generates configuration from supplied arguments and option specifications Can also generate usage strings
Structs
| Config | Specifies a configuration of parsed arguments
Each option which was given as a spec can be accessed by option(name)
This returns a Option<Vec |
| OptionSpec | Specifies an option that can be given in the command line |
Enums
| OptionPolicy | Determines how the number of supplied values should match an argument 0 val indicates a switch like argument |